package com.hungraim.ltc.governance.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.api.OrganFeignService;
import com.hungraim.ltc.governance.dao.*;
import com.hungraim.ltc.governance.service.AprOrganService;
import com.hungraim.ltc.pojo.entity.assessment.ChAprEmp;
import com.hungraim.ltc.pojo.entity.assessment.ChCfgAprGroupDetail;
import com.hungraim.ltc.pojo.entity.serviceManage.ChAprOrgan;
import com.hungraim.ltc.pojo.entity.serviceManage.ChCfgAprOrganType;
import com.hungraim.ltc.pojo.entity.serviceManage.ChCfgAprempType;
import com.hungraim.ltc.pojo.entity.serviceManage.ChFndEducation;
import com.hungraim.ltc.pojo.vo.governance.AprEmpVO;
import com.hungraim.ltc.pojo.vo.governance.AprOrganVO;
import com.hungraim.ltc.util.Result;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;


@Service
@Slf4j
@AllArgsConstructor
public class AprOrganServiceImpl implements AprOrganService {

    private final OrganFeignService organFeignService;
    private final AprOrganMapper aprOrganMapper;
    private final AprEmpMapper aprEmpMapper;
    private final ChCfgAprOrganTypeMapper cfgAprOrganTypeMapper;
    private final ChCfgAprGroupDetailMapper cfgAprGroupDetailMapper;
    private final CfgAprempMapper cfgAprempMapper;
    private final FndEducationMapper fndEducationMapper;

    @Override
    public Page<AprOrganVO> aprOrganList(Page<AprOrganVO> page, Long organId, Boolean isIncluded, String organName, String code) {
        Result<List<Long>> organChild = null;
        List<Long> organIds = null;
        if (organId != null) {
            if (isIncluded == null) {
                isIncluded = false;
            }
            organChild = organFeignService.getOrganChild(organId, isIncluded);
            organIds = organChild.getData();
        }
        return aprOrganMapper.aprOrganList(page, organIds, organName, code);
    }

    @Override
    public void updateAprOrganStatus(String aprOrganId, Short status) {
        ChAprOrgan chAprOrgan = aprOrganMapper.selectById(aprOrganId);
        chAprOrgan.setStatus(status);
        aprOrganMapper.updateById(chAprOrgan);
    }

    @Override
    public void addOrUpdateAprOrgan(ChAprOrgan chAprOrgan) {
        if (chAprOrgan.getAprOrganId() == null) {
            //新增
            chAprOrgan.setEffTime(new Date());
            chAprOrgan.setStatus((short) 0);
            aprOrganMapper.insert(chAprOrgan);
        } else {
            //更新
            ChAprOrgan aprOrgan = aprOrganMapper.selectById(chAprOrgan.getAprOrganId());
            aprOrgan.setAccName(chAprOrgan.getAccName());
            aprOrgan.setBankAccName(chAprOrgan.getBankAccName());
            aprOrgan.setBankNo(chAprOrgan.getBankNo());
            aprOrgan.setBankDistrictProvincial(chAprOrgan.getBankDistrictProvincial());
            aprOrgan.setBankDistrictCity(chAprOrgan.getBankDistrictCity());
            aprOrgan.setBankDistrictWebsite(chAprOrgan.getBankDistrictWebsite());
            aprOrgan.setCardType(chAprOrgan.getCardType());
            aprOrgan.setRemark(chAprOrgan.getRemark());
            aprOrgan.setDistrictProvincial(chAprOrgan.getDistrictProvincial());
            aprOrgan.setDistrictCity(chAprOrgan.getDistrictCity());
            aprOrgan.setDistrictArea(chAprOrgan.getDistrictArea());
            aprOrgan.setUnifiedSocialCreditCode(chAprOrgan.getUnifiedSocialCreditCode());
            aprOrgan.setOrganTypeId(chAprOrgan.getOrganTypeId());
            aprOrgan.setAcptArea(chAprOrgan.getAcptArea());
            aprOrgan.setAcptAddress(chAprOrgan.getAcptAddress());
            aprOrgan.setAcptStreet(chAprOrgan.getAcptStreet());
            aprOrgan.setLinkName(chAprOrgan.getLinkName());
            aprOrgan.setLinkTel(chAprOrgan.getLinkTel());
            aprOrgan.setGroupDetailId(chAprOrgan.getGroupDetailId());
            aprOrgan.setLinkMail(chAprOrgan.getLinkMail());
            aprOrganMapper.updateById(aprOrgan);
        }
    }

    @Override
    public ChAprOrgan getAprOrganInfo(Long aprOrganId) {
        return aprOrganMapper.selectById(aprOrganId);
    }

    @Override
    public List<ChCfgAprOrganType> getCfgAprOrganTypes() {
        return cfgAprOrganTypeMapper.selectList(new QueryWrapper<>());
    }

    @Override
    public List<ChCfgAprGroupDetail> getCfgAprGroupDetail() {
        return cfgAprGroupDetailMapper.selectList(new QueryWrapper<ChCfgAprGroupDetail>().eq("STATUS", 0));
    }

    @Override
    public Page<AprEmpVO> aprEmpList(Page<AprEmpVO> page, Long organId, Boolean isIncluded, String organName, String realName, String tel, String certiCode, String isLock, String empType) {
        Result<List<Long>> organChild = null;
        List<Long> organIds = null;
        if (organId != null) {
            if (isIncluded == null) {
                isIncluded = false;
            }
            organChild = organFeignService.getOrganChild(organId, isIncluded);
            organIds = organChild.getData();
        }
        return aprOrganMapper.aprEmpList(page, organIds, organName, realName, tel, certiCode, isLock, empType);
    }

    @Override
    public void addOrUpdateAprEmp(ChAprEmp chAprEmp) {
        if (chAprEmp.getEmpId() == null) {
            //新增
            chAprEmp.setEffTime(new Date());
            aprEmpMapper.insert(chAprEmp);
        } else {
            //更新
            ChAprEmp aprEmp = aprEmpMapper.selectById(chAprEmp.getEmpId());
            aprEmp.setTel(chAprEmp.getTel());
            aprEmp.setAprempTypeIdF(chAprEmp.getAprempTypeIdF());
            aprEmp.setAprempTypeIdS(chAprEmp.getAprempTypeIdS());
            aprEmp.setEduId(chAprEmp.getEduId());
            aprEmpMapper.updateById(aprEmp);
        }
    }

    @Override
    public List<ChCfgAprempType> cfgAprEmpType(String parAprempTypeId) {
        if (StringUtils.isBlank(parAprempTypeId)) {
            //父类型资质
            QueryWrapper<ChCfgAprempType> queryWrapper = new QueryWrapper<ChCfgAprempType>();
            queryWrapper.isNull("PAR_APREMP_TYPE_ID").or().eq("PAR_APREMP_TYPE_ID", "");
            return cfgAprempMapper.selectList(queryWrapper);
        } else {
            //根据父类型资质查询子类型资质
            return cfgAprempMapper.selectList(new QueryWrapper<ChCfgAprempType>().eq("PAR_APREMP_TYPE_ID", parAprempTypeId));
        }
    }

    @Override
    public List<ChFndEducation> fndEducation() {
        return fndEducationMapper.selectList(new QueryWrapper<>());
    }
}
